<?php
defined('_JEXEC') or die('Restricted access');


/**
 * Class that helps to utilize new filesystem layout: [userid/extension/file]
 * Note: uses singletone pattern %))
 * @author Nurlan
 *
 */
class JSPT_Res_File_Manager extends JObject
{


	/**
	 * Fetches filemanager instance
	 * @return JS_Res_File_Manager Filemanager instance
	 */
	function & getInstance() {
		static $instance = 0;
		if (!$instance) {
			$instance = new JSPT_Res_File_Manager();
		}
		return $instance;
	}




	/**
	 * Copies <b>newly</b> uploaded file to it's predefined place
	 *
	 * @param $filename string The file name
	 * @param $destName string The destination file name
	 * @param $userId int The owner of the file
	 * @param $dir string The nested directory
	 * @param $move boolean
	 * @return mixed Saved file name, null on bad args.
	 */
	function storeFile($filename, $destName, $userId, $dir = '', $move = false, $suffix) {
		// userId may be 0
		if (!$filename || is_null($userId))
		return null;
			
		if (!$destName)
		$destName = $filename;
			
		$userId = (int)$userId;

		$inFile = $this->getPath($filename, $userId);
		$ext = strtolower(JFile::getExt( $destName ));
		$destName = JFile::stripExt($destName).$suffix.'.'.$ext;

		$destFile = $this->getPath($destName, $userId, $dir);
		// Make sure these files are allowed to use
		if ( !$this->isAllowedExtension(JFile::getExt($inFile)) )
		return false;
		if ( !$this->isAllowedExtension(JFile::getExt($destFile)) )
		return false;

		if ($inFile == $destFile)
		return $destFile;

		if (JFile::exists($inFile))
		{
			$folder = dirname($destFile);
			if (!JFolder::exists($folder))
			JFolder::create($folder);

			if (!JFile::copy($inFile, $destFile)) {
				JError::raiseError(JText::_('Cannot copy').' <b>'.$inFile.'</b> '.JText::_('to').' <b> '.$destFile.'</b>');
			}
			if ($move)
			JFile::delete($inFile);
			return $destFile;
		}

		return false;
	}

	/**
	 * Returns file's path
	 * @param $file
	 * @param $userId
	 * @param $dir
	 * @return unknown_type
	 */
	function getPath($file, $userId, $dir = '') {
		$file = JFile::makeSafe($file);
		$userId = (int)$userId;

		$ext = strtolower(JFile::getExt( $file ));
		if ($ext == 'jpeg') {
			$ext = 'jpg';
			$file = JFile::stripExt($file).'.'.$ext;
		}

		$ret = RES_GENERAL_UPLOAD.DS.$userId.DS.$ext;

		if ($dir != '') 		$ret = $dir;
		$ret .= DS. $file;

		JPath::check($ret);

		return JPath::clean($ret);
	}

	/**
	 * Assigns files to new user.
	 * @param $files array
	 * @param $articleId string
	 * @param $prevAuthor int
	 * @param $currentAuthor int
	 * @param $directory string
	 * @return unknown_type
	 */
	function reassignFiles($files, $articleId, $prevAuthor, $newAuthor, $directory = '', $suffix) {
		jimport('joomla.filesystem.file');
		jimport('joomla.filesystem.folder');

		settype($files, 'array');
		$prevAuthor 	= (int)$prevAuthor;
		$newAuthor 	= (int)$newAuthor;

		$folder = RES_GENERAL_UPLOAD;

		foreach($files as $f)
		{
			if (!$f)
			continue;

			$f = basename( $f );
			$ext = JString::strtolower(JFile::getExt( $f ));
			if ($ext == 'jpeg')
			$ext = 'jpg';

			$f = JFile::makeSafe(JFile::stripExt( $f ).'.'.$ext);

			$infile = JPath::clean($folder.DS.$prevAuthor.DS.$ext.DS.$articleId.'_'.$f);
				
			$f = JFile::stripExt( $f ).$suffix.'.'.$ext;
				
			$destFile = JPath::clean($directory.DS.$newAuthor.DS.$f);
			
			$dir = dirname($destFile);
			if (!JFolder::exists($dir))
			JFolder::create($dir);

			if (JFile::exists($infile))
			{
				if (JFile::exists($destFile))
				JFile::delete($destFile);

				JFile::copy($infile, $destFile);
				JFile::delete($infile);
			}
		}
	}



	/**
	 * Checks if the extension is allowed to download
	 * @param $ext string Extension to check
	 * @return unknown_type
	 */
	function isAllowedExtension($ext) {
		if ( isset($this->_allowedExtensions[$ext]) ) {
			return $this->_allowedExtensions[$ext];
		}
		return true;
	}

	/**
	 * Add extension to allowed extension list
	 * @param $exts mixed extension
	 * @return void
	 */
	function allowExtension($exts) {
		settype($exts, 'array');

		foreach ($exts as $ext) {
			$ext = JFile::makeSafe($ext);
			// avoid dots in extension
			if (strpos($ext, '.') !== false)
			$ext = JFile::getExt($ext);

			$this->_allowedExtensions [$ext] = true;
		}
	}


	/**
	 * Initializes com_resource settings
	 * @return void
	 */
	function _initResourceConfig() {
		static $isInitialized = 0;

		if (!$isInitialized)
		{
			jimport ('joomla.filesystem.file');
			jimport ('joomla.filesystem.folder');

			require_once (JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_resource'.DS.'controllers'.DS.'config.php');
			ResControllerConfig::initialyze();

			// Include the com_resource main controller to access it's methods
			require_once JPATH_ROOT.DS.'components'.DS.'com_resource'.DS.'controller.php';

			$isInitialized = 1;
		}
	}
}

?>